nxp-pac

Crates

git

Versions

mcxa256

Flavors

Protlvl

Struct Protlvl 

#[repr(transparent)]
pub struct Protlvl(pub u32);
Protect Level Control

Tuple Fields

0: u32

Implementations

Source

impl Protlvl

pub const fn priv_(&self) -> bool

Control privileged access of EIM, ERM, Flexcan, MBC, SCG.

pub const fn set_priv_(&mut self, val: bool)

Control privileged access of EIM, ERM, Flexcan, MBC, SCG.

pub const fn locknsmpu(&self) -> Locknsmpu

Control write access to Nonsecure MPU memory regions.

pub const fn set_locknsmpu(&mut self, val: Locknsmpu)

Control write access to Nonsecure MPU memory regions.

pub const fn lock(&self) -> ProtlvlLock

This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.

pub const fn set_lock(&mut self, val: ProtlvlLock)

This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.