nxp-pac

Crates

git

Versions

mcxa256

Flavors

RamCtrl

Struct RamCtrl 

#[repr(transparent)]
pub struct RamCtrl(pub u32);
RAM Control

Tuple Fields

0: u32

Implementations

Source

impl RamCtrl

pub const fn rama_ecc_enable(&self) -> bool

RAMA ECC enable

pub const fn set_rama_ecc_enable(&mut self, val: bool)

RAMA ECC enable

pub const fn rama_cg_override(&self) -> bool

RAMA bank clock gating control, only avaiable when RAMA_ECC_ENABLE = 0.

pub const fn set_rama_cg_override(&mut self, val: bool)

RAMA bank clock gating control, only avaiable when RAMA_ECC_ENABLE = 0.

pub const fn ramx_cg_override(&self) -> bool

RAMX bank clock gating control

pub const fn set_ramx_cg_override(&mut self, val: bool)

RAMX bank clock gating control

pub const fn ramb_cg_override(&self) -> bool

RAMB bank clock gating control

pub const fn set_ramb_cg_override(&mut self, val: bool)

RAMB bank clock gating control

pub const fn ramc_cg_override(&self) -> bool

RAMC bank clock gating control

pub const fn set_ramc_cg_override(&mut self, val: bool)

RAMC bank clock gating control