#[repr(transparent)]pub struct Protlvl(pub u32);Expand description
Protect Level Control
Tuple Fields
0: u32Implementations
Sourceimpl Protlvl
impl Protlvl
Sourcepub const fn set_priv_(&mut self, val: bool)
pub const fn set_priv_(&mut self, val: bool)
Control privileged access of EIM, ERM, Flexcan, MBC, SCG.
Sourcepub const fn locknsmpu(&self) -> Locknsmpu
pub const fn locknsmpu(&self) -> Locknsmpu
Control write access to Nonsecure MPU memory regions.
Sourcepub const fn set_locknsmpu(&mut self, val: Locknsmpu)
pub const fn set_locknsmpu(&mut self, val: Locknsmpu)
Control write access to Nonsecure MPU memory regions.
Sourcepub const fn lock(&self) -> ProtlvlLock
pub const fn lock(&self) -> ProtlvlLock
This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.
Sourcepub const fn set_lock(&mut self, val: ProtlvlLock)
pub const fn set_lock(&mut self, val: ProtlvlLock)
This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.