#[repr(transparent)]pub struct SramXen(pub u32);Expand description
RAM XEN Control
Tuple Fields
0: u32Implementations
Sourceimpl SramXen
impl SramXen
Sourcepub const fn set_ramx0_xen(&mut self, val: bool)
pub const fn set_ramx0_xen(&mut self, val: bool)
RAMX0 Execute permission control.
Sourcepub const fn set_ramx1_xen(&mut self, val: bool)
pub const fn set_ramx1_xen(&mut self, val: bool)
RAMX1 Execute permission control.
Sourcepub const fn set_rama0_xen(&mut self, val: bool)
pub const fn set_rama0_xen(&mut self, val: bool)
RAMA0 Execute permission control.
Sourcepub const fn set_rama1_xen(&mut self, val: bool)
pub const fn set_rama1_xen(&mut self, val: bool)
RAMAx (excepts RAMA0) Execute permission control.
Sourcepub const fn set_ramb_xen(&mut self, val: bool)
pub const fn set_ramb_xen(&mut self, val: bool)
RAMBx Execute permission control.
Sourcepub const fn set_ramc_xen(&mut self, val: bool)
pub const fn set_ramc_xen(&mut self, val: bool)
RAMCx Execute permission control.
Sourcepub const fn lock(&self) -> SramXenLock
pub const fn lock(&self) -> SramXenLock
This 1-bit field provides a mechanism to limit writes to the this register (and SRAM_XEN_DP) to protect its contents. Once set, this bit remains asserted until a system reset.
Sourcepub const fn set_lock(&mut self, val: SramXenLock)
pub const fn set_lock(&mut self, val: SramXenLock)
This 1-bit field provides a mechanism to limit writes to the this register (and SRAM_XEN_DP) to protect its contents. Once set, this bit remains asserted until a system reset.